<h1 align = "center">:rocket: Hyperopt :facepunch:</h1>

---

> 底层库networkx更新造成的Bug，Hyperopt不支持networkx-2.0，换成`pip install networkx==1.11`

## 1. [hpsklearn][1]

## 2. [hyperas][2]




---
[1]: https://github.com/hyperopt/hyperopt-sklearn
[2]: https://github.com/maxpumperla/hyperas
